"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTimeFromBCD24 = exports.getTimeFromMJD = exports.sleep = exports.updateObject = exports.ChannelTypes = void 0;
var ChannelTypes;
(function (ChannelTypes) {
    ChannelTypes["GR"] = "GR";
    ChannelTypes["BS"] = "BS";
    ChannelTypes["CS"] = "CS";
    ChannelTypes["SKY"] = "SKY";
})(ChannelTypes = exports.ChannelTypes || (exports.ChannelTypes = {}));
function updateObject(target, input) {
    let updated = false;
    for (const k in input) {
        if (Array.isArray(target[k]) && Array.isArray(input[k])) {
            updated = updateArray(target[k], input[k]) || updated;
            continue;
        }
        else if (target[k] === null && input[k] === null) {
            continue;
        }
        else if (typeof target[k] === "object" && typeof input[k] === "object") {
            updated = updateObject(target[k], input[k]) || updated;
            continue;
        }
        else if (target[k] === input[k]) {
            continue;
        }
        target[k] = input[k];
        updated = true;
    }
    return updated;
}
exports.updateObject = updateObject;
function updateArray(target, input) {
    const length = target.length;
    if (length !== input.length) {
        target.splice(0, length, ...input);
        return true;
    }
    let updated = false;
    for (let i = 0; i < length; i++) {
        if (Array.isArray(target[i]) && Array.isArray(input[i])) {
            updated = updateArray(target[i], input[i]) || updated;
            continue;
        }
        else if (target[i] === null && input[i] === null) {
            continue;
        }
        else if (typeof target[i] === "object" && typeof input[i] === "object") {
            updated = updateObject(target[i], input[i]) || updated;
            continue;
        }
        else if (target[i] === input[i]) {
            continue;
        }
        target[i] = input[i];
        updated = true;
    }
    return updated;
}
function sleep(ms) {
    return new Promise(resolve => {
        setTimeout(resolve, ms);
    });
}
exports.sleep = sleep;
function getTimeFromMJD(buffer) {
    const mjd = (buffer[0] << 8) | buffer[1];
    const h = (buffer[2] >> 4) * 10 + (buffer[2] & 0x0F);
    const i = (buffer[3] >> 4) * 10 + (buffer[3] & 0x0F);
    const s = (buffer[4] >> 4) * 10 + (buffer[4] & 0x0F);
    return ((mjd - 40587) * 86400 + ((h - 9) * 60 * 60) + (i * 60) + s) * 1000;
}
exports.getTimeFromMJD = getTimeFromMJD;
function getTimeFromBCD24(buffer) {
    let time = ((buffer[0] >> 4) * 10 + (buffer[0] & 0x0F)) * 3600;
    time += ((buffer[1] >> 4) * 10 + (buffer[1] & 0x0F)) * 60;
    time += (buffer[2] >> 4) * 10 + (buffer[2] & 0x0F);
    return time * 1000;
}
exports.getTimeFromBCD24 = getTimeFromBCD24;
//# sourceMappingURL=common.js.map